@@ -116,7 +116,7 @@ class AttributeLogger(Device):
         logged_values = self._get_logged_attributes()
         last_log_line = self.separator.join(logged_values)
         self.set_raw_value(ATTR_LAST_LOG_LINE, last_log_line)
-        if self.attribute_logger:
+        if self.attribute_logger is not None:
             self.attribute_logger.info(last_log_line)
 
     def add_logged_attribute(self, device_id, attribute):
