@@ -153,7 +153,8 @@ class DeviceVirtualDirectory(DeviceFileServer):
         path_hash, file_size, file_mod_time = self.get_meta_hash(drive, input_dir, file_name)
         path_hash = "/".join((cache_directory, path_hash))
         if os.path.exists(path_hash):
-            if file_size == os.path.getsize(path_hash) and file_mod_time == os.path.getmtime(path_hash):
+            # if file_size == os.path.getsize(path_hash) and file_mod_time == os.path.getmtime(path_hash):
+            if file_mod_time == os.path.getmtime(path_hash):
                 return True, path_hash
 
         return False, path_hash
