@@ -211,7 +211,8 @@ class ScanAttributeWidget(Ui_Form, MacroWidget):
                     scanner_attributes = scanner.get_scanner_attributes()
                     for attribute in scanner_attributes:
                         self.macro_widgets.append(
-                            self._show_method_attribute_widget(attribute, scanner.get_attribute(attribute).attribute_copy(),
+                            self._show_method_attribute_widget(attribute,
+                                                               scanner.get_attribute(attribute).attribute_copy(),
                                                                row))
                         row += 1
                 except AttributeError:
@@ -450,7 +451,8 @@ class ScanAttributeWidget(Ui_Form, MacroWidget):
                             scanner_attributes=scanner_attributes, return_back=self.config.get("return_back", True))
             else:
                 scan = Scan("Scan", values["start_point"], values["end_point"], int(values["total_steps"].m),
-                            repeat_count=values["repeat"], random_deviation=values["random_deviation"], step_class=StepDeviceAttributeNumerical,
+                            repeat_count=values["repeat"], random_deviation=values["random_deviation"],
+                            step_class=StepDeviceAttributeNumerical,
                             step_attributes=step_attributes, as_step=False,
                             bidirectional=self.config.get("bidirectional", False), scanner=scanner,
                             scanner_attributes=scanner_attributes, return_back=self.config.get("return_back", True))
