@@ -225,7 +225,7 @@ class Macro(Common, Device):
                     # Set point index of macro
                     self.set_point_index(self.current_point_index + 1)
                     # Write into log file if trigger_log is set and we have logger associated
-                    if link.trigger_log and self.macro_logger:
+                    if link.trigger_log and self.macro_logger is not None:
                         self.macro_logger.trigger()
 
                     if link.repeated == link.repeat_count:
